# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BlueprintArgs', 'Blueprint']

@pulumi.input_type
class BlueprintArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[str],
                 content: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 request_scope_org: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Blueprint resource.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[bool] request_scope_org: Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        """
        pulumi.set(__self__, "project_id", project_id)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if request_scope_org is not None:
            pulumi.set(__self__, "request_scope_org", request_scope_org)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        ID of project that entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="requestScopeOrg")
    def request_scope_org(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        """
        return pulumi.get(self, "request_scope_org")

    @request_scope_org.setter
    def request_scope_org(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "request_scope_org", value)


@pulumi.input_type
class _BlueprintState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[str]] = None,
                 content_source_id: Optional[pulumi.Input[str]] = None,
                 content_source_path: Optional[pulumi.Input[str]] = None,
                 content_source_sync_at: Optional[pulumi.Input[str]] = None,
                 content_source_sync_messages: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 content_source_sync_status: Optional[pulumi.Input[str]] = None,
                 content_source_type: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 request_scope_org: Optional[pulumi.Input[bool]] = None,
                 self_link: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 total_released_versions: Optional[pulumi.Input[int]] = None,
                 total_versions: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 updated_by: Optional[pulumi.Input[str]] = None,
                 valid: Optional[pulumi.Input[bool]] = None,
                 validation_messages: Optional[pulumi.Input[Sequence[pulumi.Input['BlueprintValidationMessageArgs']]]] = None):
        """
        Input properties used for looking up and filtering Blueprint resources.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] content_source_id: ID of content source.
        :param pulumi.Input[str] content_source_path: Content source path.
        :param pulumi.Input[str] content_source_sync_at: Date when content source was last synced. The date is in ISO 8601 and UTC.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_source_sync_messages: Content source last sync messages.
        :param pulumi.Input[str] content_source_sync_status: Content source last sync status. Supported values: `SUCCESSFUL`, `FAILED`.
        :param pulumi.Input[str] content_source_type: Content source type.
        :param pulumi.Input[str] created_at: Date when entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[str] created_by: The user who created entity.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[str] project_name: Name of project that entity belongs to.
        :param pulumi.Input[bool] request_scope_org: Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        :param pulumi.Input[str] self_link: HATEOAS of entity.
        :param pulumi.Input[str] status: Status of cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        :param pulumi.Input[int] total_released_versions: Total number of released versions.
        :param pulumi.Input[int] total_versions: Total number of versions.
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] updated_by: The user who last updated the entity.
        :param pulumi.Input[bool] valid: Flag to indicate if the current content of the cloud template/blueprint is valid.
        :param pulumi.Input[Sequence[pulumi.Input['BlueprintValidationMessageArgs']]] validation_messages: List of validations messages.
               * message - Validation message.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if content_source_id is not None:
            pulumi.set(__self__, "content_source_id", content_source_id)
        if content_source_path is not None:
            pulumi.set(__self__, "content_source_path", content_source_path)
        if content_source_sync_at is not None:
            pulumi.set(__self__, "content_source_sync_at", content_source_sync_at)
        if content_source_sync_messages is not None:
            pulumi.set(__self__, "content_source_sync_messages", content_source_sync_messages)
        if content_source_sync_status is not None:
            pulumi.set(__self__, "content_source_sync_status", content_source_sync_status)
        if content_source_type is not None:
            pulumi.set(__self__, "content_source_type", content_source_type)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if request_scope_org is not None:
            pulumi.set(__self__, "request_scope_org", request_scope_org)
        if self_link is not None:
            pulumi.set(__self__, "self_link", self_link)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if total_released_versions is not None:
            pulumi.set(__self__, "total_released_versions", total_released_versions)
        if total_versions is not None:
            pulumi.set(__self__, "total_versions", total_versions)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)
        if valid is not None:
            pulumi.set(__self__, "valid", valid)
        if validation_messages is not None:
            pulumi.set(__self__, "validation_messages", validation_messages)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="contentSourceId")
    def content_source_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of content source.
        """
        return pulumi.get(self, "content_source_id")

    @content_source_id.setter
    def content_source_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_source_id", value)

    @property
    @pulumi.getter(name="contentSourcePath")
    def content_source_path(self) -> Optional[pulumi.Input[str]]:
        """
        Content source path.
        """
        return pulumi.get(self, "content_source_path")

    @content_source_path.setter
    def content_source_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_source_path", value)

    @property
    @pulumi.getter(name="contentSourceSyncAt")
    def content_source_sync_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when content source was last synced. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "content_source_sync_at")

    @content_source_sync_at.setter
    def content_source_sync_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_source_sync_at", value)

    @property
    @pulumi.getter(name="contentSourceSyncMessages")
    def content_source_sync_messages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Content source last sync messages.
        """
        return pulumi.get(self, "content_source_sync_messages")

    @content_source_sync_messages.setter
    def content_source_sync_messages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "content_source_sync_messages", value)

    @property
    @pulumi.getter(name="contentSourceSyncStatus")
    def content_source_sync_status(self) -> Optional[pulumi.Input[str]]:
        """
        Content source last sync status. Supported values: `SUCCESSFUL`, `FAILED`.
        """
        return pulumi.get(self, "content_source_sync_status")

    @content_source_sync_status.setter
    def content_source_sync_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_source_sync_status", value)

    @property
    @pulumi.getter(name="contentSourceType")
    def content_source_type(self) -> Optional[pulumi.Input[str]]:
        """
        Content source type.
        """
        return pulumi.get(self, "content_source_type")

    @content_source_type.setter
    def content_source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_source_type", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user who created entity.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of project that entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of project that entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="requestScopeOrg")
    def request_scope_org(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        """
        return pulumi.get(self, "request_scope_org")

    @request_scope_org.setter
    def request_scope_org(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "request_scope_org", value)

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> Optional[pulumi.Input[str]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "self_link")

    @self_link.setter
    def self_link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "self_link", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="totalReleasedVersions")
    def total_released_versions(self) -> Optional[pulumi.Input[int]]:
        """
        Total number of released versions.
        """
        return pulumi.get(self, "total_released_versions")

    @total_released_versions.setter
    def total_released_versions(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_released_versions", value)

    @property
    @pulumi.getter(name="totalVersions")
    def total_versions(self) -> Optional[pulumi.Input[int]]:
        """
        Total number of versions.
        """
        return pulumi.get(self, "total_versions")

    @total_versions.setter
    def total_versions(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_versions", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user who last updated the entity.
        """
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_by", value)

    @property
    @pulumi.getter
    def valid(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag to indicate if the current content of the cloud template/blueprint is valid.
        """
        return pulumi.get(self, "valid")

    @valid.setter
    def valid(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "valid", value)

    @property
    @pulumi.getter(name="validationMessages")
    def validation_messages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlueprintValidationMessageArgs']]]]:
        """
        List of validations messages.
        * message - Validation message.
        """
        return pulumi.get(self, "validation_messages")

    @validation_messages.setter
    def validation_messages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlueprintValidationMessageArgs']]]]):
        pulumi.set(self, "validation_messages", value)


class Blueprint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 request_scope_org: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation (vRA) cloud template resource, formerly known as a blueprint.

        ## Example Usage

        The following example shows how to create a blueprint resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.blueprint.Blueprint("this",
            description="Created by vRA terraform provider",
            project_id=vra_project["this"]["id"],
            content=f\"\"\"formatVersion: 1
        inputs:
          image:
            type: string
            description: "Image"
          flavor:
            type: string
            description: "Flavor"
        resources:
          Machine:
            type: Cloud.Machine
            properties:
              image: {input["image"]}
              flavor: {input["flavor"]}
        \"\"\")
        ```

        ## Import

        To import the cloud template, use the ID as in the following example

        ```sh
         $ pulumi import vra:blueprint/blueprint:Blueprint this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[bool] request_scope_org: Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BlueprintArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation (vRA) cloud template resource, formerly known as a blueprint.

        ## Example Usage

        The following example shows how to create a blueprint resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.blueprint.Blueprint("this",
            description="Created by vRA terraform provider",
            project_id=vra_project["this"]["id"],
            content=f\"\"\"formatVersion: 1
        inputs:
          image:
            type: string
            description: "Image"
          flavor:
            type: string
            description: "Flavor"
        resources:
          Machine:
            type: Cloud.Machine
            properties:
              image: {input["image"]}
              flavor: {input["flavor"]}
        \"\"\")
        ```

        ## Import

        To import the cloud template, use the ID as in the following example

        ```sh
         $ pulumi import vra:blueprint/blueprint:Blueprint this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param BlueprintArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BlueprintArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 request_scope_org: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BlueprintArgs.__new__(BlueprintArgs)

            __props__.__dict__["content"] = content
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["request_scope_org"] = request_scope_org
            __props__.__dict__["content_source_id"] = None
            __props__.__dict__["content_source_path"] = None
            __props__.__dict__["content_source_sync_at"] = None
            __props__.__dict__["content_source_sync_messages"] = None
            __props__.__dict__["content_source_sync_status"] = None
            __props__.__dict__["content_source_type"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["project_name"] = None
            __props__.__dict__["self_link"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["total_released_versions"] = None
            __props__.__dict__["total_versions"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["updated_by"] = None
            __props__.__dict__["valid"] = None
            __props__.__dict__["validation_messages"] = None
        super(Blueprint, __self__).__init__(
            'vra:blueprint/blueprint:Blueprint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[str]] = None,
            content_source_id: Optional[pulumi.Input[str]] = None,
            content_source_path: Optional[pulumi.Input[str]] = None,
            content_source_sync_at: Optional[pulumi.Input[str]] = None,
            content_source_sync_messages: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            content_source_sync_status: Optional[pulumi.Input[str]] = None,
            content_source_type: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            request_scope_org: Optional[pulumi.Input[bool]] = None,
            self_link: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            total_released_versions: Optional[pulumi.Input[int]] = None,
            total_versions: Optional[pulumi.Input[int]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            updated_by: Optional[pulumi.Input[str]] = None,
            valid: Optional[pulumi.Input[bool]] = None,
            validation_messages: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlueprintValidationMessageArgs']]]]] = None) -> 'Blueprint':
        """
        Get an existing Blueprint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: Blueprint YAML content.
        :param pulumi.Input[str] content_source_id: ID of content source.
        :param pulumi.Input[str] content_source_path: Content source path.
        :param pulumi.Input[str] content_source_sync_at: Date when content source was last synced. The date is in ISO 8601 and UTC.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] content_source_sync_messages: Content source last sync messages.
        :param pulumi.Input[str] content_source_sync_status: Content source last sync status. Supported values: `SUCCESSFUL`, `FAILED`.
        :param pulumi.Input[str] content_source_type: Content source type.
        :param pulumi.Input[str] created_at: Date when entity was created. The date is in ISO 8601 and UTC.
        :param pulumi.Input[str] created_by: The user who created entity.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] project_id: ID of project that entity belongs to.
        :param pulumi.Input[str] project_name: Name of project that entity belongs to.
        :param pulumi.Input[bool] request_scope_org: Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        :param pulumi.Input[str] self_link: HATEOAS of entity.
        :param pulumi.Input[str] status: Status of cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        :param pulumi.Input[int] total_released_versions: Total number of released versions.
        :param pulumi.Input[int] total_versions: Total number of versions.
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] updated_by: The user who last updated the entity.
        :param pulumi.Input[bool] valid: Flag to indicate if the current content of the cloud template/blueprint is valid.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlueprintValidationMessageArgs']]]] validation_messages: List of validations messages.
               * message - Validation message.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BlueprintState.__new__(_BlueprintState)

        __props__.__dict__["content"] = content
        __props__.__dict__["content_source_id"] = content_source_id
        __props__.__dict__["content_source_path"] = content_source_path
        __props__.__dict__["content_source_sync_at"] = content_source_sync_at
        __props__.__dict__["content_source_sync_messages"] = content_source_sync_messages
        __props__.__dict__["content_source_sync_status"] = content_source_sync_status
        __props__.__dict__["content_source_type"] = content_source_type
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["request_scope_org"] = request_scope_org
        __props__.__dict__["self_link"] = self_link
        __props__.__dict__["status"] = status
        __props__.__dict__["total_released_versions"] = total_released_versions
        __props__.__dict__["total_versions"] = total_versions
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["updated_by"] = updated_by
        __props__.__dict__["valid"] = valid
        __props__.__dict__["validation_messages"] = validation_messages
        return Blueprint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[Optional[str]]:
        """
        Blueprint YAML content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentSourceId")
    def content_source_id(self) -> pulumi.Output[str]:
        """
        ID of content source.
        """
        return pulumi.get(self, "content_source_id")

    @property
    @pulumi.getter(name="contentSourcePath")
    def content_source_path(self) -> pulumi.Output[str]:
        """
        Content source path.
        """
        return pulumi.get(self, "content_source_path")

    @property
    @pulumi.getter(name="contentSourceSyncAt")
    def content_source_sync_at(self) -> pulumi.Output[str]:
        """
        Date when content source was last synced. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "content_source_sync_at")

    @property
    @pulumi.getter(name="contentSourceSyncMessages")
    def content_source_sync_messages(self) -> pulumi.Output[Sequence[str]]:
        """
        Content source last sync messages.
        """
        return pulumi.get(self, "content_source_sync_messages")

    @property
    @pulumi.getter(name="contentSourceSyncStatus")
    def content_source_sync_status(self) -> pulumi.Output[str]:
        """
        Content source last sync status. Supported values: `SUCCESSFUL`, `FAILED`.
        """
        return pulumi.get(self, "content_source_sync_status")

    @property
    @pulumi.getter(name="contentSourceType")
    def content_source_type(self) -> pulumi.Output[str]:
        """
        Content source type.
        """
        return pulumi.get(self, "content_source_type")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when entity was created. The date is in ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        The user who created entity.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        ID of project that entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        Name of project that entity belongs to.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="requestScopeOrg")
    def request_scope_org(self) -> pulumi.Output[bool]:
        """
        Flag to indicate whether blueprint can be requested from any project in the organization that entity belongs to.
        """
        return pulumi.get(self, "request_scope_org")

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> pulumi.Output[str]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "self_link")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Status of cloud template. Supported values: `DRAFT`, `VERSIONED`, `RELEASED`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalReleasedVersions")
    def total_released_versions(self) -> pulumi.Output[int]:
        """
        Total number of released versions.
        """
        return pulumi.get(self, "total_released_versions")

    @property
    @pulumi.getter(name="totalVersions")
    def total_versions(self) -> pulumi.Output[int]:
        """
        Total number of versions.
        """
        return pulumi.get(self, "total_versions")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[str]:
        """
        The user who last updated the entity.
        """
        return pulumi.get(self, "updated_by")

    @property
    @pulumi.getter
    def valid(self) -> pulumi.Output[bool]:
        """
        Flag to indicate if the current content of the cloud template/blueprint is valid.
        """
        return pulumi.get(self, "valid")

    @property
    @pulumi.getter(name="validationMessages")
    def validation_messages(self) -> pulumi.Output[Sequence['outputs.BlueprintValidationMessage']]:
        """
        List of validations messages.
        * message - Validation message.
        """
        return pulumi.get(self, "validation_messages")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetSnapshotsResult',
    'AwaitableGetSnapshotsResult',
    'get_snapshots',
    'get_snapshots_output',
]

@pulumi.output_type
class GetSnapshotsResult:
    """
    A collection of values returned by getSnapshots.
    """
    def __init__(__self__, block_device_id=None, id=None, snapshots=None):
        if block_device_id and not isinstance(block_device_id, str):
            raise TypeError("Expected argument 'block_device_id' to be a str")
        pulumi.set(__self__, "block_device_id", block_device_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if snapshots and not isinstance(snapshots, list):
            raise TypeError("Expected argument 'snapshots' to be a list")
        pulumi.set(__self__, "snapshots", snapshots)

    @property
    @pulumi.getter(name="blockDeviceId")
    def block_device_id(self) -> str:
        return pulumi.get(self, "block_device_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def snapshots(self) -> Sequence['outputs.GetSnapshotsSnapshotResult']:
        return pulumi.get(self, "snapshots")


class AwaitableGetSnapshotsResult(GetSnapshotsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSnapshotsResult(
            block_device_id=self.block_device_id,
            id=self.id,
            snapshots=self.snapshots)


def get_snapshots(block_device_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSnapshotsResult:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: blockdevice.get_snapshots"
    description: |-
      Provides a data lookup for vra_block_device_snapshots.
    ---

    # Data Source: blockdevice.get_snapshots
    ## Example Usage
    """
    __args__ = dict()
    __args__['blockDeviceId'] = block_device_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:blockdevice/getSnapshots:getSnapshots', __args__, opts=opts, typ=GetSnapshotsResult).value

    return AwaitableGetSnapshotsResult(
        block_device_id=__ret__.block_device_id,
        id=__ret__.id,
        snapshots=__ret__.snapshots)


@_utilities.lift_output_func(get_snapshots)
def get_snapshots_output(block_device_id: Optional[pulumi.Input[str]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSnapshotsResult]:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: blockdevice.get_snapshots"
    description: |-
      Provides a data lookup for vra_block_device_snapshots.
    ---

    # Data Source: blockdevice.get_snapshots
    ## Example Usage
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ContentSourceArgs', 'ContentSource']

@pulumi.input_type
class ContentSourceArgs:
    def __init__(__self__, *,
                 config: pulumi.Input['ContentSourceConfigArgs'],
                 project_id: pulumi.Input[str],
                 sync_enabled: pulumi.Input[bool],
                 type_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ContentSource resource.
        :param pulumi.Input['ContentSourceConfigArgs'] config: Content source custom configuration.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[bool] sync_enabled: Flag indicating whether sync is enabled for this content source.
        :param pulumi.Input[str] type_id: Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] name: A human-friendly name for content source used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "config", config)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "sync_enabled", sync_enabled)
        pulumi.set(__self__, "type_id", type_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Input['ContentSourceConfigArgs']:
        """
        Content source custom configuration.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: pulumi.Input['ContentSourceConfigArgs']):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="syncEnabled")
    def sync_enabled(self) -> pulumi.Input[bool]:
        """
        Flag indicating whether sync is enabled for this content source.
        """
        return pulumi.get(self, "sync_enabled")

    @sync_enabled.setter
    def sync_enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "sync_enabled", value)

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> pulumi.Input[str]:
        """
        Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        return pulumi.get(self, "type_id")

    @type_id.setter
    def type_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "type_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name for content source used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ContentSourceState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input['ContentSourceConfigArgs']] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 created_by: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 last_updated_at: Optional[pulumi.Input[str]] = None,
                 last_updated_by: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 sync_enabled: Optional[pulumi.Input[bool]] = None,
                 type_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ContentSource resources.
        :param pulumi.Input['ContentSourceConfigArgs'] config: Content source custom configuration.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] created_by: The user the entity was created by.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] last_updated_at: Date when the entity was last updated. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] last_updated_by: The user the entity was last updated by.
        :param pulumi.Input[str] name: A human-friendly name for content source used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[bool] sync_enabled: Flag indicating whether sync is enabled for this content source.
        :param pulumi.Input[str] type_id: Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if last_updated_at is not None:
            pulumi.set(__self__, "last_updated_at", last_updated_at)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sync_enabled is not None:
            pulumi.set(__self__, "sync_enabled", sync_enabled)
        if type_id is not None:
            pulumi.set(__self__, "type_id", type_id)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['ContentSourceConfigArgs']]:
        """
        Content source custom configuration.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['ContentSourceConfigArgs']]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_by", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "last_updated_at")

    @last_updated_at.setter
    def last_updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_updated_at", value)

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user the entity was last updated by.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_updated_by", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name for content source used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="syncEnabled")
    def sync_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag indicating whether sync is enabled for this content source.
        """
        return pulumi.get(self, "sync_enabled")

    @sync_enabled.setter
    def sync_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sync_enabled", value)

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> Optional[pulumi.Input[str]]:
        """
        Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        return pulumi.get(self, "type_id")

    @type_id.setter
    def type_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type_id", value)


class ContentSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['ContentSourceConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 sync_enabled: Optional[pulumi.Input[bool]] = None,
                 type_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides a way to create a content source vRealize Automation(vRA).

        ## Example Usage
        ### S

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.contentsource.ContentSource("this",
            project_id=var["project_id"],
            type_id="com.gitlab",
            description="Some content Source",
            sync_enabled=False,
            config=vra.contentsource.ContentSourceConfigArgs(
                path="blueprint01",
                branch="master",
                repository="vracontent/vra8_content_source_test",
                content_type="BLUEPRINT",
                project_name=var["project_name"],
                integration_id=var["integration_id"],
            ))
        ```

        ## Import

        Content source can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:contentsource/contentSource:ContentSource this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ContentSourceConfigArgs']] config: Content source custom configuration.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] name: A human-friendly name for content source used as an identifier in APIs that support this option.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[bool] sync_enabled: Flag indicating whether sync is enabled for this content source.
        :param pulumi.Input[str] type_id: Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContentSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides a way to create a content source vRealize Automation(vRA).

        ## Example Usage
        ### S

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.contentsource.ContentSource("this",
            project_id=var["project_id"],
            type_id="com.gitlab",
            description="Some content Source",
            sync_enabled=False,
            config=vra.contentsource.ContentSourceConfigArgs(
                path="blueprint01",
                branch="master",
                repository="vracontent/vra8_content_source_test",
                content_type="BLUEPRINT",
                project_name=var["project_name"],
                integration_id=var["integration_id"],
            ))
        ```

        ## Import

        Content source can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:contentsource/contentSource:ContentSource this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param ContentSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContentSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[pulumi.InputType['ContentSourceConfigArgs']]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 sync_enabled: Optional[pulumi.Input[bool]] = None,
                 type_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContentSourceArgs.__new__(ContentSourceArgs)

            if config is None and not opts.urn:
                raise TypeError("Missing required property 'config'")
            __props__.__dict__["config"] = config
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if sync_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'sync_enabled'")
            __props__.__dict__["sync_enabled"] = sync_enabled
            if type_id is None and not opts.urn:
                raise TypeError("Missing required property 'type_id'")
            __props__.__dict__["type_id"] = type_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["last_updated_at"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["org_id"] = None
        super(ContentSource, __self__).__init__(
            'vra:contentsource/contentSource:ContentSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[pulumi.InputType['ContentSourceConfigArgs']]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            created_by: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            last_updated_at: Optional[pulumi.Input[str]] = None,
            last_updated_by: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            sync_enabled: Optional[pulumi.Input[bool]] = None,
            type_id: Optional[pulumi.Input[str]] = None) -> 'ContentSource':
        """
        Get an existing ContentSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['ContentSourceConfigArgs']] config: Content source custom configuration.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] created_by: The user the entity was created by.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] last_updated_at: Date when the entity was last updated. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] last_updated_by: The user the entity was last updated by.
        :param pulumi.Input[str] name: A human-friendly name for content source used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: The id of the organization this entity belongs to.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        :param pulumi.Input[bool] sync_enabled: Flag indicating whether sync is enabled for this content source.
        :param pulumi.Input[str] type_id: Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContentSourceState.__new__(_ContentSourceState)

        __props__.__dict__["config"] = config
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["last_updated_at"] = last_updated_at
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["sync_enabled"] = sync_enabled
        __props__.__dict__["type_id"] = type_id
        return ContentSource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def config(self) -> pulumi.Output['outputs.ContentSourceConfig']:
        """
        Content source custom configuration.
        """
        return pulumi.get(self, "config")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[str]:
        """
        The user the entity was created by.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="lastUpdatedAt")
    def last_updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "last_updated_at")

    @property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[str]:
        """
        The user the entity was last updated by.
        """
        return pulumi.get(self, "last_updated_by")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name for content source used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="syncEnabled")
    def sync_enabled(self) -> pulumi.Output[bool]:
        """
        Flag indicating whether sync is enabled for this content source.
        """
        return pulumi.get(self, "sync_enabled")

    @property
    @pulumi.getter(name="typeId")
    def type_id(self) -> pulumi.Output[str]:
        """
        Content Source type. Supported values are `com.gitlab`, `com.github`, `com.vmware.marketplace`, `org.bitbucket`.
        """
        return pulumi.get(self, "type_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProfileResult',
    'AwaitableGetProfileResult',
    'get_profile',
    'get_profile_output',
]

@pulumi.output_type
class GetProfileResult:
    """
    A collection of values returned by getProfile.
    """
    def __init__(__self__, custom_properties=None, description=None, external_region_id=None, fabric_network_ids=None, filter=None, id=None, isolated_external_fabric_network_id=None, isolated_network_cidr_prefix=None, isolated_network_domain_cidr=None, isolated_network_domain_id=None, isolation_type=None, links=None, name=None, organization_id=None, owner=None, region_id=None, security_group_ids=None, tags=None, updated_at=None):
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if fabric_network_ids and not isinstance(fabric_network_ids, list):
            raise TypeError("Expected argument 'fabric_network_ids' to be a list")
        pulumi.set(__self__, "fabric_network_ids", fabric_network_ids)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if isolated_external_fabric_network_id and not isinstance(isolated_external_fabric_network_id, str):
            raise TypeError("Expected argument 'isolated_external_fabric_network_id' to be a str")
        pulumi.set(__self__, "isolated_external_fabric_network_id", isolated_external_fabric_network_id)
        if isolated_network_cidr_prefix and not isinstance(isolated_network_cidr_prefix, int):
            raise TypeError("Expected argument 'isolated_network_cidr_prefix' to be a int")
        pulumi.set(__self__, "isolated_network_cidr_prefix", isolated_network_cidr_prefix)
        if isolated_network_domain_cidr and not isinstance(isolated_network_domain_cidr, str):
            raise TypeError("Expected argument 'isolated_network_domain_cidr' to be a str")
        pulumi.set(__self__, "isolated_network_domain_cidr", isolated_network_domain_cidr)
        if isolated_network_domain_id and not isinstance(isolated_network_domain_id, str):
            raise TypeError("Expected argument 'isolated_network_domain_id' to be a str")
        pulumi.set(__self__, "isolated_network_domain_id", isolated_network_domain_id)
        if isolation_type and not isinstance(isolation_type, str):
            raise TypeError("Expected argument 'isolation_type' to be a str")
        pulumi.set(__self__, "isolation_type", isolation_type)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if region_id and not isinstance(region_id, str):
            raise TypeError("Expected argument 'region_id' to be a str")
        pulumi.set(__self__, "region_id", region_id)
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        """
        Additional properties that may be used to extend the Network Profile object that is produced from this specification. For isolationType security group, datastoreId identifies the Compute Resource Edge datastore. computeCluster and resourcePoolId identify the Compute Resource Edge cluster. For isolationType subnet, distributedLogicalRouterStateLink identifies the on-demand network distributed local router. onDemandNetworkIPAssignmentType identifies the on-demand network IP range assignment type static, dynamic, or mixed.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The external regionId of the resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="fabricNetworkIds")
    def fabric_network_ids(self) -> Sequence[str]:
        """
        A list of fabric network Ids which are assigned to the network profile.
        example:[ "6543" ]
        """
        return pulumi.get(self, "fabric_network_ids")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isolatedExternalFabricNetworkId")
    def isolated_external_fabric_network_id(self) -> Optional[str]:
        return pulumi.get(self, "isolated_external_fabric_network_id")

    @property
    @pulumi.getter(name="isolatedNetworkCidrPrefix")
    def isolated_network_cidr_prefix(self) -> int:
        """
        The CIDR prefix length to be used for the isolated networks that are created with the network profile.
        """
        return pulumi.get(self, "isolated_network_cidr_prefix")

    @property
    @pulumi.getter(name="isolatedNetworkDomainCidr")
    def isolated_network_domain_cidr(self) -> str:
        """
        CIDR of the isolation network domain.
        """
        return pulumi.get(self, "isolated_network_domain_cidr")

    @property
    @pulumi.getter(name="isolatedNetworkDomainId")
    def isolated_network_domain_id(self) -> Optional[str]:
        return pulumi.get(self, "isolated_network_domain_id")

    @property
    @pulumi.getter(name="isolationType")
    def isolation_type(self) -> str:
        """
        Specifies the isolation type e.g. none, subnet or security group
        """
        return pulumi.get(self, "isolation_type")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetProfileLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> str:
        """
        The id of the region for which this profile is defined as in vRealize Automation(vRA).
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Sequence[str]:
        """
        A list of security group Ids which are assigned to the network profile.
        example:[ "6545" ]
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetProfileTagResult']:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetProfileResult(GetProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProfileResult(
            custom_properties=self.custom_properties,
            description=self.description,
            external_region_id=self.external_region_id,
            fabric_network_ids=self.fabric_network_ids,
            filter=self.filter,
            id=self.id,
            isolated_external_fabric_network_id=self.isolated_external_fabric_network_id,
            isolated_network_cidr_prefix=self.isolated_network_cidr_prefix,
            isolated_network_domain_cidr=self.isolated_network_domain_cidr,
            isolated_network_domain_id=self.isolated_network_domain_id,
            isolation_type=self.isolation_type,
            links=self.links,
            name=self.name,
            organization_id=self.organization_id,
            owner=self.owner,
            region_id=self.region_id,
            security_group_ids=self.security_group_ids,
            tags=self.tags,
            updated_at=self.updated_at)


def get_profile(filter: Optional[str] = None,
                id: Optional[str] = None,
                isolated_external_fabric_network_id: Optional[str] = None,
                isolated_network_domain_id: Optional[str] = None,
                tags: Optional[Sequence[pulumi.InputType['GetProfileTagArgs']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProfileResult:
    """
    ## Example Usage
    ### S
    This is an example of how to create a network profile resource.

    **Network profile data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_profile(filter=f"name eq '{vra_network_profile['this']['name']}'")
    ```

    **Vra network profile data source filter by region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_profile(filter=f"regionId eq '{data['vra_region']['this']['id']}'")
    ```

    A network profile data source supports the following arguments:


    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param str isolated_external_fabric_network_id: The Id of the fabric network used for outbound access.
    :param str isolated_network_domain_id: The Id of the network domain used for creating isolated networks.
    :param Sequence[pulumi.InputType['GetProfileTagArgs']] tags: A set of tag keys and optional values that were set on this Network Profile.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['isolatedExternalFabricNetworkId'] = isolated_external_fabric_network_id
    __args__['isolatedNetworkDomainId'] = isolated_network_domain_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:network/getProfile:getProfile', __args__, opts=opts, typ=GetProfileResult).value

    return AwaitableGetProfileResult(
        custom_properties=__ret__.custom_properties,
        description=__ret__.description,
        external_region_id=__ret__.external_region_id,
        fabric_network_ids=__ret__.fabric_network_ids,
        filter=__ret__.filter,
        id=__ret__.id,
        isolated_external_fabric_network_id=__ret__.isolated_external_fabric_network_id,
        isolated_network_cidr_prefix=__ret__.isolated_network_cidr_prefix,
        isolated_network_domain_cidr=__ret__.isolated_network_domain_cidr,
        isolated_network_domain_id=__ret__.isolated_network_domain_id,
        isolation_type=__ret__.isolation_type,
        links=__ret__.links,
        name=__ret__.name,
        organization_id=__ret__.organization_id,
        owner=__ret__.owner,
        region_id=__ret__.region_id,
        security_group_ids=__ret__.security_group_ids,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_profile)
def get_profile_output(filter: Optional[pulumi.Input[Optional[str]]] = None,
                       id: Optional[pulumi.Input[Optional[str]]] = None,
                       isolated_external_fabric_network_id: Optional[pulumi.Input[Optional[str]]] = None,
                       isolated_network_domain_id: Optional[pulumi.Input[Optional[str]]] = None,
                       tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProfileTagArgs']]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProfileResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to create a network profile resource.

    **Network profile data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_profile(filter=f"name eq '{vra_network_profile['this']['name']}'")
    ```

    **Vra network profile data source filter by region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.network.get_profile(filter=f"regionId eq '{data['vra_region']['this']['id']}'")
    ```

    A network profile data source supports the following arguments:


    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param str isolated_external_fabric_network_id: The Id of the fabric network used for outbound access.
    :param str isolated_network_domain_id: The Id of the network domain used for creating isolated networks.
    :param Sequence[pulumi.InputType['GetProfileTagArgs']] tags: A set of tag keys and optional values that were set on this Network Profile.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAzureResult',
    'AwaitableGetAzureResult',
    'get_azure',
    'get_azure_output',
]

@pulumi.output_type
class GetAzureResult:
    """
    A collection of values returned by getAzure.
    """
    def __init__(__self__, cloud_account_id=None, created_at=None, data_disk_caching=None, default_item=None, description=None, disk_type=None, external_region_id=None, filter=None, id=None, links=None, name=None, org_id=None, os_disk_caching=None, owner=None, supports_encryption=None, tags=None, updated_at=None):
        if cloud_account_id and not isinstance(cloud_account_id, str):
            raise TypeError("Expected argument 'cloud_account_id' to be a str")
        pulumi.set(__self__, "cloud_account_id", cloud_account_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if data_disk_caching and not isinstance(data_disk_caching, str):
            raise TypeError("Expected argument 'data_disk_caching' to be a str")
        pulumi.set(__self__, "data_disk_caching", data_disk_caching)
        if default_item and not isinstance(default_item, bool):
            raise TypeError("Expected argument 'default_item' to be a bool")
        pulumi.set(__self__, "default_item", default_item)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if disk_type and not isinstance(disk_type, str):
            raise TypeError("Expected argument 'disk_type' to be a str")
        pulumi.set(__self__, "disk_type", disk_type)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if os_disk_caching and not isinstance(os_disk_caching, str):
            raise TypeError("Expected argument 'os_disk_caching' to be a str")
        pulumi.set(__self__, "os_disk_caching", os_disk_caching)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if supports_encryption and not isinstance(supports_encryption, bool):
            raise TypeError("Expected argument 'supports_encryption' to be a bool")
        pulumi.set(__self__, "supports_encryption", supports_encryption)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountId")
    def cloud_account_id(self) -> str:
        return pulumi.get(self, "cloud_account_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="dataDiskCaching")
    def data_disk_caching(self) -> str:
        """
        Indicates the caching mechanism for additional disk.
        """
        return pulumi.get(self, "data_disk_caching")

    @property
    @pulumi.getter(name="defaultItem")
    def default_item(self) -> bool:
        """
        Indicates if this storage profile is a default profile.
        """
        return pulumi.get(self, "default_item")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> str:
        """
        Indicates the performance tier for the storage type. Premium disks are SSD backed and Standard disks are HDD backed.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region as seen in the cloud provider for which this profile is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetAzureLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="osDiskCaching")
    def os_disk_caching(self) -> str:
        """
        Indicates the caching mechanism for OS disk. Default policy for OS disks is Read/Write.
        """
        return pulumi.get(self, "os_disk_caching")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="supportsEncryption")
    def supports_encryption(self) -> bool:
        """
        Indicates whether this storage policy should support encryption or not.
        """
        return pulumi.get(self, "supports_encryption")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetAzureTagResult']:
        """
        A set of tag keys and optional values that were set on this Network Profile.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetAzureResult(GetAzureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureResult(
            cloud_account_id=self.cloud_account_id,
            created_at=self.created_at,
            data_disk_caching=self.data_disk_caching,
            default_item=self.default_item,
            description=self.description,
            disk_type=self.disk_type,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            os_disk_caching=self.os_disk_caching,
            owner=self.owner,
            supports_encryption=self.supports_encryption,
            tags=self.tags,
            updated_at=self.updated_at)


def get_azure(filter: Optional[str] = None,
              id: Optional[str] = None,
              tags: Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureResult:
    """
    ## Example Usage
    ### S
    This is an example of how to create a storage profile azure resource.

    **Storage profile azure data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.storageprofile.get_azure(id=vra_storage_profile_azure["this"]["id"])
    ```

    **Vra storage profile data source filter by external region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.storageprofile.get_azure(filter="externalRegionId eq 'foobar'")
    ```

    A storage profile azure data source supports the following arguments:


    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this Network Profile.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['id'] = id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:storageprofile/getAzure:getAzure', __args__, opts=opts, typ=GetAzureResult).value

    return AwaitableGetAzureResult(
        cloud_account_id=__ret__.cloud_account_id,
        created_at=__ret__.created_at,
        data_disk_caching=__ret__.data_disk_caching,
        default_item=__ret__.default_item,
        description=__ret__.description,
        disk_type=__ret__.disk_type,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        os_disk_caching=__ret__.os_disk_caching,
        owner=__ret__.owner,
        supports_encryption=__ret__.supports_encryption,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_azure)
def get_azure_output(filter: Optional[pulumi.Input[Optional[str]]] = None,
                     id: Optional[pulumi.Input[Optional[str]]] = None,
                     tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAzureTagArgs']]]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAzureResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to create a storage profile azure resource.

    **Storage profile azure data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.storageprofile.get_azure(id=vra_storage_profile_azure["this"]["id"])
    ```

    **Vra storage profile data source filter by external region id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.storageprofile.get_azure(filter="externalRegionId eq 'foobar'")
    ```

    A storage profile azure data source supports the following arguments:


    :param str filter: Filter query string that is supported by vRA multi-cloud IaaS API. Example: regionId eq '<regionId>' and cloudAccountId eq '<cloudAccountId>'.
    :param str id: The id of the image profile instance.
    :param Sequence[pulumi.InputType['GetAzureTagArgs']] tags: A set of tag keys and optional values that were set on this Network Profile.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'BlockDeviceConstraint',
    'BlockDeviceLink',
    'BlockDeviceSnapshot',
    'BlockDeviceSnapshotLink',
    'BlockDeviceTag',
    'SnapshotLink',
    'GetBlockDeviceLinkResult',
    'GetBlockDeviceSnapshotResult',
    'GetBlockDeviceSnapshotLinkResult',
    'GetBlockDeviceTagResult',
    'GetSnapshotsSnapshotResult',
    'GetSnapshotsSnapshotLinkResult',
]

@pulumi.output_type
class BlockDeviceConstraint(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class BlockDeviceLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class BlockDeviceSnapshot(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createdAt":
            suggest = "created_at"
        elif key == "isCurrent":
            suggest = "is_current"
        elif key == "orgId":
            suggest = "org_id"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in BlockDeviceSnapshot. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        BlockDeviceSnapshot.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        BlockDeviceSnapshot.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 created_at: Optional[str] = None,
                 description: Optional[str] = None,
                 id: Optional[str] = None,
                 is_current: Optional[bool] = None,
                 links: Optional[Sequence['outputs.BlockDeviceSnapshotLink']] = None,
                 name: Optional[str] = None,
                 org_id: Optional[str] = None,
                 owner: Optional[str] = None,
                 updated_at: Optional[str] = None):
        """
        :param str created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param str description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param str id: ID of the block device snapshot.
        :param bool is_current: Indicates whether snapshot on block device is current.
        :param Sequence['BlockDeviceSnapshotLinkArgs'] links: HATEOAS of the entity
        :param str name: Human-friendly name used as an identifier in APIs that support this option.
        :param str org_id: ID of organization that block device snapshot belongs to.
        :param str owner: Email of block device snapshot owner.
        :param str updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_current is not None:
            pulumi.set(__self__, "is_current", is_current)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[str]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        ID of the block device snapshot.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> Optional[bool]:
        """
        Indicates whether snapshot on block device is current.
        """
        return pulumi.get(self, "is_current")

    @property
    @pulumi.getter
    def links(self) -> Optional[Sequence['outputs.BlockDeviceSnapshotLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[str]:
        """
        ID of organization that block device snapshot belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> Optional[str]:
        """
        Email of block device snapshot owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[str]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class BlockDeviceSnapshotLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class BlockDeviceTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class SnapshotLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetBlockDeviceLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetBlockDeviceSnapshotResult(dict):
    def __init__(__self__, *,
                 created_at: str,
                 description: str,
                 id: str,
                 is_current: bool,
                 links: Sequence['outputs.GetBlockDeviceSnapshotLinkResult'],
                 name: str,
                 org_id: str,
                 owner: str,
                 updated_at: str):
        """
        :param str created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param str description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param str id: The id of the block device.
        :param Sequence['GetBlockDeviceSnapshotLinkArgs'] links: HATEOAS of the entity.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        :param str org_id: The id of the organization this entity belongs to.
        :param str owner: Email of the user that owns the entity.
        :param str updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_current", is_current)
        pulumi.set(__self__, "links", links)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the block device.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> bool:
        return pulumi.get(self, "is_current")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetBlockDeviceSnapshotLinkResult']:
        """
        HATEOAS of the entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class GetBlockDeviceSnapshotLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class GetBlockDeviceTagResult(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetSnapshotsSnapshotResult(dict):
    def __init__(__self__, *,
                 created_at: str,
                 description: str,
                 id: str,
                 is_current: bool,
                 links: Sequence['outputs.GetSnapshotsSnapshotLinkResult'],
                 name: str,
                 org_id: str,
                 owner: str,
                 updated_at: str):
        """
        :param str created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param str description: A human-friendly description.
        :param bool is_current: Indicates whether this snapshot is the current snapshot on the block-device.
        :param Sequence['GetSnapshotsSnapshotLinkArgs'] links: HATEOAS of the entity
        :param str name: A human-friendly name used as an identifier in APIs that support this option.  Only one of 'filter', 'id', 'name' or 'region_id' must be specified.
        :param str org_id: The id of the organization this entity belongs to.
        :param str owner: Email of the user that owns the entity.
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "is_current", is_current)
        pulumi.set(__self__, "links", links)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "owner", owner)
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isCurrent")
    def is_current(self) -> bool:
        """
        Indicates whether this snapshot is the current snapshot on the block-device.
        """
        return pulumi.get(self, "is_current")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetSnapshotsSnapshotLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.  Only one of 'filter', 'id', 'name' or 'region_id' must be specified.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class GetSnapshotsSnapshotLinkResult(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IpRangeArgs', 'IpRange']

@pulumi.input_type
class IpRangeArgs:
    def __init__(__self__, *,
                 end_ip_address: pulumi.Input[str],
                 ip_version: pulumi.Input[str],
                 start_ip_address: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 fabric_network_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]] = None):
        """
        The set of arguments for constructing a IpRange resource.
        :param pulumi.Input[str] end_ip_address: End IP address of the range.
        :param pulumi.Input[str] ip_version: IP address version: IPv4 or IPv6. Default: IPv4.
        :param pulumi.Input[str] start_ip_address: Start IP address of the range.
        :param pulumi.Input[str] description: State object representing a network on a external cloud provider.
        :param pulumi.Input[str] fabric_network_id: Fabric network Id.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        pulumi.set(__self__, "end_ip_address", end_ip_address)
        pulumi.set(__self__, "ip_version", ip_version)
        pulumi.set(__self__, "start_ip_address", start_ip_address)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if fabric_network_id is not None:
            pulumi.set(__self__, "fabric_network_id", fabric_network_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="endIpAddress")
    def end_ip_address(self) -> pulumi.Input[str]:
        """
        End IP address of the range.
        """
        return pulumi.get(self, "end_ip_address")

    @end_ip_address.setter
    def end_ip_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "end_ip_address", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Input[str]:
        """
        IP address version: IPv4 or IPv6. Default: IPv4.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="startIpAddress")
    def start_ip_address(self) -> pulumi.Input[str]:
        """
        Start IP address of the range.
        """
        return pulumi.get(self, "start_ip_address")

    @start_ip_address.setter
    def start_ip_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "start_ip_address", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        State object representing a network on a external cloud provider.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="fabricNetworkId")
    def fabric_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        Fabric network Id.
        """
        return pulumi.get(self, "fabric_network_id")

    @fabric_network_id.setter
    def fabric_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fabric_network_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _IpRangeState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 end_ip_address: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 fabric_network_id: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 start_ip_address: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IpRange resources.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] description: State object representing a network on a external cloud provider.
        :param pulumi.Input[str] end_ip_address: End IP address of the range.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] fabric_network_id: Fabric network Id.
        :param pulumi.Input[str] ip_version: IP address version: IPv4 or IPv6. Default: IPv4.
        :param pulumi.Input[Sequence[pulumi.Input['IpRangeLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] start_ip_address: Start IP address of the range.
        :param pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if end_ip_address is not None:
            pulumi.set(__self__, "end_ip_address", end_ip_address)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if fabric_network_id is not None:
            pulumi.set(__self__, "fabric_network_id", fabric_network_id)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if start_ip_address is not None:
            pulumi.set(__self__, "start_ip_address", start_ip_address)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        State object representing a network on a external cloud provider.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="endIpAddress")
    def end_ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        End IP address of the range.
        """
        return pulumi.get(self, "end_ip_address")

    @end_ip_address.setter
    def end_ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_ip_address", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="fabricNetworkId")
    def fabric_network_id(self) -> Optional[pulumi.Input[str]]:
        """
        Fabric network Id.
        """
        return pulumi.get(self, "fabric_network_id")

    @fabric_network_id.setter
    def fabric_network_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fabric_network_id", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        IP address version: IPv4 or IPv6. Default: IPv4.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="startIpAddress")
    def start_ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        Start IP address of the range.
        """
        return pulumi.get(self, "start_ip_address")

    @start_ip_address.setter
    def start_ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_ip_address", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpRangeTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class IpRange(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 end_ip_address: Optional[pulumi.Input[str]] = None,
                 fabric_network_id: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 start_ip_address: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeTagArgs']]]]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation network_ip_range resource.

        ## Example Usage

        ## Import

        To import the vRA Network IP range, use the ID as in the following example

        ```sh
         $ pulumi import vra:network/ipRange:IpRange new_ip_range 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: State object representing a network on a external cloud provider.
        :param pulumi.Input[str] end_ip_address: End IP address of the range.
        :param pulumi.Input[str] fabric_network_id: Fabric network Id.
        :param pulumi.Input[str] ip_version: IP address version: IPv4 or IPv6. Default: IPv4.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] start_ip_address: Start IP address of the range.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeTagArgs']]]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpRangeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation network_ip_range resource.

        ## Example Usage

        ## Import

        To import the vRA Network IP range, use the ID as in the following example

        ```sh
         $ pulumi import vra:network/ipRange:IpRange new_ip_range 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param IpRangeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpRangeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 end_ip_address: Optional[pulumi.Input[str]] = None,
                 fabric_network_id: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 start_ip_address: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpRangeArgs.__new__(IpRangeArgs)

            __props__.__dict__["description"] = description
            if end_ip_address is None and not opts.urn:
                raise TypeError("Missing required property 'end_ip_address'")
            __props__.__dict__["end_ip_address"] = end_ip_address
            __props__.__dict__["fabric_network_id"] = fabric_network_id
            if ip_version is None and not opts.urn:
                raise TypeError("Missing required property 'ip_version'")
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["name"] = name
            if start_ip_address is None and not opts.urn:
                raise TypeError("Missing required property 'start_ip_address'")
            __props__.__dict__["start_ip_address"] = start_ip_address
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["updated_at"] = None
        super(IpRange, __self__).__init__(
            'vra:network/ipRange:IpRange',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            end_ip_address: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            fabric_network_id: Optional[pulumi.Input[str]] = None,
            ip_version: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            start_ip_address: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'IpRange':
        """
        Get an existing IpRange resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: Date when the entity was created. The date is in ISO 6801 and UTC.
        :param pulumi.Input[str] description: State object representing a network on a external cloud provider.
        :param pulumi.Input[str] end_ip_address: End IP address of the range.
        :param pulumi.Input[str] external_id: External entity Id on the provider side.
        :param pulumi.Input[str] fabric_network_id: Fabric network Id.
        :param pulumi.Input[str] ip_version: IP address version: IPv4 or IPv6. Default: IPv4.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] start_ip_address: Start IP address of the range.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['IpRangeTagArgs']]]] tags: Set of tag keys and values to apply to the resource.
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpRangeState.__new__(_IpRangeState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["end_ip_address"] = end_ip_address
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["fabric_network_id"] = fabric_network_id
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["start_ip_address"] = start_ip_address
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return IpRange(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        State object representing a network on a external cloud provider.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="endIpAddress")
    def end_ip_address(self) -> pulumi.Output[str]:
        """
        End IP address of the range.
        """
        return pulumi.get(self, "end_ip_address")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="fabricNetworkId")
    def fabric_network_id(self) -> pulumi.Output[Optional[str]]:
        """
        Fabric network Id.
        """
        return pulumi.get(self, "fabric_network_id")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[str]:
        """
        IP address version: IPv4 or IPv6. Default: IPv4.
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.IpRangeLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="startIpAddress")
    def start_ip_address(self) -> pulumi.Output[str]:
        """
        Start IP address of the range.
        """
        return pulumi.get(self, "start_ip_address")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.IpRangeTag']]:
        """
        Set of tag keys and values to apply to the resource.
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ItemEntitlementArgs', 'ItemEntitlement']

@pulumi.input_type
class ItemEntitlementArgs:
    def __init__(__self__, *,
                 catalog_item_id: pulumi.Input[str],
                 project_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ItemEntitlement resource.
        :param pulumi.Input[str] catalog_item_id: The id of the catalog item to create the entitlement.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        """
        pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        pulumi.set(__self__, "project_id", project_id)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> pulumi.Input[str]:
        """
        The id of the catalog item to create the entitlement.
        """
        return pulumi.get(self, "catalog_item_id")

    @catalog_item_id.setter
    def catalog_item_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "catalog_item_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _ItemEntitlementState:
    def __init__(__self__, *,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 definitions: Optional[pulumi.Input[Sequence[pulumi.Input['ItemEntitlementDefinitionArgs']]]] = None,
                 project_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ItemEntitlement resources.
        :param pulumi.Input[str] catalog_item_id: The id of the catalog item to create the entitlement.
        :param pulumi.Input[Sequence[pulumi.Input['ItemEntitlementDefinitionArgs']]] definitions: Represents a catalog item that is linked to a project via an entitlement.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        """
        if catalog_item_id is not None:
            pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if definitions is not None:
            pulumi.set(__self__, "definitions", definitions)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the catalog item to create the entitlement.
        """
        return pulumi.get(self, "catalog_item_id")

    @catalog_item_id.setter
    def catalog_item_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_id", value)

    @property
    @pulumi.getter
    def definitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ItemEntitlementDefinitionArgs']]]]:
        """
        Represents a catalog item that is linked to a project via an entitlement.
        """
        return pulumi.get(self, "definitions")

    @definitions.setter
    def definitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ItemEntitlementDefinitionArgs']]]]):
        pulumi.set(self, "definitions", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)


class ItemEntitlement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides a way to create a catalog item entitlement in VMware vRealize Automation.

        ## Example Usage
        ### S

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.catalog.ItemEntitlement("this",
            catalog_item_id=var["catalog_item_id"],
            project_id=var["project_id"])
        ```

        ## Import

        Catalog item entitlement can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:catalog/itemEntitlement:ItemEntitlement this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] catalog_item_id: The id of the catalog item to create the entitlement.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ItemEntitlementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides a way to create a catalog item entitlement in VMware vRealize Automation.

        ## Example Usage
        ### S

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.catalog.ItemEntitlement("this",
            catalog_item_id=var["catalog_item_id"],
            project_id=var["project_id"])
        ```

        ## Import

        Catalog item entitlement can be imported using the id, e.g.

        ```sh
         $ pulumi import vra:catalog/itemEntitlement:ItemEntitlement this 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param ItemEntitlementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ItemEntitlementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ItemEntitlementArgs.__new__(ItemEntitlementArgs)

            if catalog_item_id is None and not opts.urn:
                raise TypeError("Missing required property 'catalog_item_id'")
            __props__.__dict__["catalog_item_id"] = catalog_item_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["definitions"] = None
        super(ItemEntitlement, __self__).__init__(
            'vra:catalog/itemEntitlement:ItemEntitlement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            catalog_item_id: Optional[pulumi.Input[str]] = None,
            definitions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ItemEntitlementDefinitionArgs']]]]] = None,
            project_id: Optional[pulumi.Input[str]] = None) -> 'ItemEntitlement':
        """
        Get an existing ItemEntitlement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] catalog_item_id: The id of the catalog item to create the entitlement.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ItemEntitlementDefinitionArgs']]]] definitions: Represents a catalog item that is linked to a project via an entitlement.
        :param pulumi.Input[str] project_id: The id of the project this entity belongs to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ItemEntitlementState.__new__(_ItemEntitlementState)

        __props__.__dict__["catalog_item_id"] = catalog_item_id
        __props__.__dict__["definitions"] = definitions
        __props__.__dict__["project_id"] = project_id
        return ItemEntitlement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> pulumi.Output[str]:
        """
        The id of the catalog item to create the entitlement.
        """
        return pulumi.get(self, "catalog_item_id")

    @property
    @pulumi.getter
    def definitions(self) -> pulumi.Output[Sequence['outputs.ItemEntitlementDefinition']]:
        """
        Represents a catalog item that is linked to a project via an entitlement.
        """
        return pulumi.get(self, "definitions")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The id of the project this entity belongs to.
        """
        return pulumi.get(self, "project_id")

